##  Viewing Synchronization Logs
Every 24 hours, SAP extension discovery generates synchronization logs for each discovery run. It retrieves this data from SAP Build. You can use the synchronization logs to identify integration issues and get details on each failed integration run.
To access the synchronization logs, do the following:
  1. In the administration area of SAP LeanIX, go to **Integrations**.
  2. Choose **Sync Log**.
  3. Use the filters to find SAP Build in the table.


For more information on synchronization logs, refer to [Synchronization Logging](https://help.sap.com/docs/leanix/ea/synchronization-logging?locale=en-US&state=PRODUCTION&version=CLOUD "Use synchronization logs to track the state of your integrations.").
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
